Interface: ChartConfigurationCustomTypesPerDataset | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: ChartConfigurationCustomTypesPerDataset<TType, TData, TLabel>

## # Type parameters

Name | Type
--- | ---
`TType` | extends `ChartType` = `ChartType`
`TData` | `DefaultDataPoint`<`TType`>
`TLabel` | `unknown`

## # Properties

### # data

• data: `ChartDataCustomTypesPerDataset`<`TType`, `TData`, `TLabel`>

#### # Defined in

index.esm.d.ts:3712
(opens new window)

### # options

• `Optional` options: `DeepPartial`<`CoreChartOptions`<`TType`> & `ElementChartOptions`<`TType`> & `PluginChartOptions`<`TType`> & `DatasetChartOptions`<`TType`> & `ScaleChartOptions`<`TType`> & `ChartTypeRegistry`[`TType`][`"chartOptions"`]>

#### # Defined in

index.esm.d.ts:3713
(opens new window)

### # plugins

• `Optional` plugins: `Plugin`<`TType`, `AnyObject`>[]

#### # Defined in

index.esm.d.ts:3714
(opens new window)